ColorConverter class
A class that implements JsonConverter to convert Color objects to and from JSON.
Constructors
- ColorConverter()
-
A class that implements JsonConverter to convert Color objects to and from JSON.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fromJson(
String json) → Color - Converts a hexadecimal color string from JSON to a Color object.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
Color color) → String - Converts a Color object to a hexadecimal color string for JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited