DateTimeConverter class

DateTimeConverter that parses and formats dates in the selected format. For example:

class Example {
const Example(this.date);
@DateTimeConverter.yyyyMMdd()
final DateTime date;
}

Constructors

DateTimeConverter.HHmm()
Creates a DateTimeConverter that parses and formats dates in the format HH:mm.
const
DateTimeConverter.yyyyMMdd()
Creates a DateTimeConverter that parses and formats dates in the format yyyy-MM-dd.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromJson(String json) DateTime
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(DateTime time) String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited