convertResponse<BodyType, InnerType> method
Converts the received Response to a Response which has a body of the
type BodyType.
BodyType is the expected type of the resulting Response's body
(e.g., String or CustomObject).
If BodyType is a List or a BuiltList, InnerType is the type of the
generic parameter (e.g., convertResponse<List<CustomObject>, CustomObject>(response) ).
Implementation
@override
FutureOr<Response<BodyType>> convertResponse<BodyType, InnerType>(Response<dynamic> response) async {
final jsonRes = await super.convertResponse<dynamic, dynamic>(response);
return jsonRes.copyWith<BodyType>(body: _decode<InnerType>(jsonRes.body) as BodyType);
}