Margins class
Constructors
- Margins()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- horizontal1 → const SizedBox
- horizontal2 → const SizedBox
- horizontal4 → const SizedBox
- horizontal6 → const SizedBox
- horizontal8 → const SizedBox
- horizontal10 → const SizedBox
- horizontal12 → const SizedBox
- horizontal16 → const SizedBox
- horizontal20 → const SizedBox
- horizontal24 → const SizedBox
- horizontal28 → const SizedBox
- horizontal32 → const SizedBox
- horizontal36 → const SizedBox
- horizontal40 → const SizedBox
- horizontal44 → const SizedBox
- horizontal48 → const SizedBox
- vertical1 → const SizedBox
- vertical2 → const SizedBox
- vertical4 → const SizedBox
- vertical6 → const SizedBox
- vertical8 → const SizedBox
- vertical10 → const SizedBox
- vertical12 → const SizedBox
- vertical16 → const SizedBox
- vertical20 → const SizedBox
- vertical24 → const SizedBox
- vertical28 → const SizedBox
- vertical32 → const SizedBox
- vertical36 → const SizedBox
- vertical40 → const SizedBox
- vertical44 → const SizedBox
- vertical48 → const SizedBox