debouncer/debouncer library

Classes

Debouncer
A debouncer is a utility class that allows you to debounce a function call. It is useful to prevent a function from being called too frequently. For example, if you have a function that is called when the user types in a search box, you can use a debouncer to prevent the function from being called too frequently. This is useful to prevent the server from being overwhelmed by too many requests.