charge static method

void charge(
  1. List<BoltCharge> charges
)

Add BoltCharge charges to the logger. This will start the logger if it is not already running. Without any charges, the logger will not output any logs.

Available charges:

For example to add a DebugConsoleCharge charge, use the following code snippet:

BoltLogger.charge([DebugConsoleCharge()]);

Implementation

static void charge(List<BoltCharge> charges) {
  for (final charge in charges) {
    _instance._outputs.putIfAbsent(charge.name, () => charge);
  }
  _instance._subscribeIfNeeded();
}