BoltCharge class abstract interface

Interface for creating BoltCharges to power the BoltLogger

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the charge.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

discharge() → void
Discharge the charge.
logOutput(ZapEvent event) → void
Log the output of the ZapEvent.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited