DebugConsoleCharge class

A BoltCharge that logs output to the console with ANSI color support.

Implemented types

Constructors

DebugConsoleCharge()
A BoltCharge that logs output to the console with ANSI color support.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the charge.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

discharge() → void
Discharge the charge.
override
logOutput(ZapEvent event) → void
Log the output of the ZapEvent.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited