MemoryCharge class
A BoltCharge that stores logs in memory. This will be used for viewing logs in the app. With the BoltLoggerView widget.
By default, the maxItems is set to 1000. This is the amount of logs that will be stored in memory.
- Implemented types
Constructors
- MemoryCharge({int maxItems = 1000})
- A BoltCharge that stores logs in memory. This will be used for viewing logs in the app. With the BoltLoggerView widget.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
ZapEvent> -
The list of ZapEvents currently stored in memory.
no setter
- maxItems → int
-
The maximum amount of logs to store in memory.
final
- name → String
-
The name of the charge.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
ZapEvent> -
The stream of ZapEvents.
no setter
Methods
-
discharge(
) → void -
Discharge the charge.
override
-
logOutput(
ZapEvent event) → void -
Log the output of the ZapEvent.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited