MemoryCharge constructor

MemoryCharge({
  1. int maxItems = 1000,
})

A BoltCharge that stores logs in memory. This will be used for viewing logs in the app. With the BoltLoggerView widget.

By default, the maxItems is set to 1000. This is the amount of logs that will be stored in memory.

Implementation

MemoryCharge({this.maxItems = 1000});