BoltLoggerView constructor
const
BoltLoggerView({
- Key? key,
A widget that displays the logs stored in the MemoryCharge.
Implementation
const BoltLoggerView({super.key});
A widget that displays the logs stored in the MemoryCharge.
const BoltLoggerView({super.key});