ZapEvent class

A zap event that contains the lines of a log record and the origin LogRecord.

Constructors

ZapEvent.fromRecord(LogRecord record)
Create a ZapEvent from a LogRecord.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
lines List<String>
Formatted lines of the LogRecord.
final
origin → LogRecord
The original LogRecord that was zapped.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited