onLoadMore property
void Function()?
onLoadMore
final
The function to call when the user scrolls to the bottom of the list, to load more items.
Implementation
final void Function()? onLoadMore;
The function to call when the user scrolls to the bottom of the list, to load more items.
final void Function()? onLoadMore;