hasNextPage property
bool
get
hasNextPage
Checks if there is a next page to load for the current PaginationState.
Implementation
bool get hasNextPage => currentPage < lastPage;
Checks if there is a next page to load for the current PaginationState.
bool get hasNextPage => currentPage < lastPage;