PaginationStateView<T> class

A widget that displays a different widget based on the state of the pagination

state is the state of the pagination loadingWidget is the widget to display when state is PaginationState.isLoading emptyWidget is the widget to display when state is PaginationState.items is empty errorWidget is the widget to display when state is PaginationState.hasError builder is the builder for the actual success view (usually PaginatedScrollView) onRefresh is the refresh callback for RefreshIndicator

Inheritance

Constructors

PaginationStateView({required PaginationState<T> state, required Widget loadingWidget, required Widget emptyWidget, required Widget errorWidget, required WidgetBuilder builder, RefreshCallback? onRefresh, Key? key})
Constructor
const

Properties

builder WidgetBuilder
Builder for the actual success view (usually PaginatedScrollView)
final
emptyWidget Widget
Custom widget for PaginationState.items is empty
final
errorWidget Widget
Custom widget for PaginationState.hasError
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingWidget Widget
Custom widget for PaginationState.isLoading
final
onRefresh RefreshCallback?
Optional: refresh callback for RefreshIndicator
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state PaginationState<T>
The state of the pagination
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited