ShowcaseColors class

The colors of the kit, taken from the Katjas kleurplaat of the app and from the color scheme when the app does not have one.

Constructors

ShowcaseColors({required Color surface, required Color onSurface, required Color accent})
Creates a ShowcaseColors.
const
ShowcaseColors.of(BuildContext context)
Takes the colors from the theme of context.
factory

Properties

accent → Color
final
hashCode → int
The hash code for this object.
no setterinherited
onSurface → Color
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
surface → Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited