displayMedium property
T?
get
displayMedium
The medium display text style.
Used for prominent text that is slightly smaller than displayLarge.
Implementation
T? get displayMedium;
The medium display text style.
Used for prominent text that is slightly smaller than displayLarge.
T? get displayMedium;