displaySmall property
T?
get
displaySmall
The smallest display text style.
Used for emphasized text that still needs to stand out.
Implementation
T? get displaySmall;
The smallest display text style.
Used for emphasized text that still needs to stand out.
T? get displaySmall;