titleMedium property
T?
get
titleMedium
The medium title text style.
Used for list item titles and smaller component headers.
Implementation
T? get titleMedium;
The medium title text style.
Used for list item titles and smaller component headers.
T? get titleMedium;