KleurplaatInterface<T> class abstract interface

Group of colors defined for KatjasKleurplaat.

Implementers

Properties

accent → ColorGroupInterface<T>?
The accent color group.
no setter
accentFill → ColorGroupInterface<T>?
The accent fill color group.
no setter
content → ColorGroupInterface<T>
The content color group.
no setter
contentFill → ColorGroupInterface<T>
The content fill color group.
no setter
error → ColorGroupInterface<T>
The error color group.
no setter
errorFill → ColorGroupInterface<T>
The error fill color group.
no setter
hashCode → int
The hash code for this object.
no setterinherited
primary → ColorGroupInterface<T>
The primary color group.
no setter
primaryFill → ColorGroupInterface<T>
The primary fill color group.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondary → ColorGroupInterface<T>?
The secondary color group.
no setter
secondaryFill → ColorGroupInterface<T>?
The secondary fill color group.
no setter
success → ColorGroupInterface<T>
The success color group.
no setter
successFill → ColorGroupInterface<T>
The success fill color group.
no setter
surface → SurfaceGroupInterface<T>
The surface inverse group.
no setter
surfaceInverse → SurfaceGroupInterface<T>?
The surface inverse group.
no setter
tertiary → ColorGroupInterface<T>?
The tertiary color group.
no setter
tertiaryFill → ColorGroupInterface<T>?
The tertiary fill color group.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited