SurfaceGroup class
Group of colors defined for surfaces in KatjasKleurplaat.
- Implemented types
Constructors
- SurfaceGroup({required Color color, required Color onColorContrast, required Color onColorContrastDim, required Color onColorSubtle, required Color onColorSubtleDim, required Color containerLowest, required Color containerLow, required Color container, required Color containerHigh, required Color containerHighest, required Color link})
-
Group of colors defined for surfaces in KatjasKleurplaat.
const
Properties
- color → Color
-
The color on the background.
final
- container → Color
-
The color of the container.
final
- containerHigh → Color
-
The color of the high container.
final
- containerHighest → Color
-
The color of the highest container.
final
- containerLow → Color
-
The color of the low container.
final
- containerLowest → Color
-
The color of the lowest container.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- link → Color
-
The color of the link.
final
- onColorContrast → Color
-
The color on the surface with a higher contrast.
final
- onColorContrastDim → Color
-
The color on the surface with a lower contrast.
final
- onColorSubtle → Color
-
The color on the surface with a higher contrast, but more subtle.
final
- onColorSubtleDim → Color
-
The color on the surface with a lower contrast, but more subtle.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
lerp(
covariant SurfaceGroup? other, double t) → SurfaceGroup -
Linearly interpolate with another object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited