HandschriftSurfaceGroup class

Group of colors defined for surfaces in KatjasKleurplaat.

Implemented types

Constructors

HandschriftSurfaceGroup({required Handschrift color, required Handschrift onColorContrast, required Handschrift onColorContrastDim, required Handschrift onColorSubtle, required Handschrift onColorSubtleDim, required Handschrift containerLowest, required Handschrift containerLow, required Handschrift container, required Handschrift containerHigh, required Handschrift containerHighest, required Handschrift link, Handschrift? onColorError, Handschrift? onColorSuccess, Handschrift? onColorPrimary, Handschrift? onColorPrimaryVariant})
Group of colors defined for surfaces in KatjasKleurplaat.
const

Properties

color Handschrift
The color on the background.
final
container Handschrift
The color of the container.
final
containerHigh Handschrift
The color of the high container.
final
containerHighest Handschrift
The color of the highest container.
final
containerLow Handschrift
The color of the low container.
final
containerLowest Handschrift
The color of the lowest container.
final
hashCode int
The hash code for this object.
no setterinherited
The color of the link.
final
onColorContrast Handschrift
The color on the surface with a higher contrast.
final
onColorContrastDim Handschrift
The color on the surface with a lower contrast.
final
onColorError Handschrift?
The color on the surface for error.
final
onColorPrimary Handschrift?
The color on the surface for primary.
final
onColorPrimaryVariant Handschrift?
The color on the surface for primary variant.
final
onColorSubtle Handschrift
The color on the surface with a higher contrast, but more subtle.
final
onColorSubtleDim Handschrift
The color on the surface with a lower contrast, but more subtle.
final
onColorSuccess Handschrift?
The color on the surface for success.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

lerp(covariant HandschriftSurfaceGroup? other, double t) HandschriftSurfaceGroup
Linearly interpolate with another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited