TextStyleSurfaceGroup class

Group of colors defined for surfaces in KatjasKleurplaat.

Implemented types

Constructors

TextStyleSurfaceGroup({required TextStyle color, required TextStyle onColorContrast, required TextStyle onColorContrastDim, required TextStyle onColorSubtle, required TextStyle onColorSubtleDim, required TextStyle containerLowest, required TextStyle containerLow, required TextStyle container, required TextStyle containerHigh, required TextStyle containerHighest, required TextStyle link})
Group of colors defined for surfaces in KatjasKleurplaat.
const

Properties

color TextStyle
The color on the background.
final
container TextStyle
The color of the container.
final
containerHigh TextStyle
The color of the high container.
final
containerHighest TextStyle
The color of the highest container.
final
containerLow TextStyle
The color of the low container.
final
containerLowest TextStyle
The color of the lowest container.
final
hashCode int
The hash code for this object.
no setterinherited
The color of the link.
final
onColorContrast TextStyle
The color on the surface with a higher contrast.
final
onColorContrastDim TextStyle
The color on the surface with a lower contrast.
final
onColorSubtle TextStyle
The color on the surface with a higher contrast, but more subtle.
final
onColorSubtleDim TextStyle
The color on the surface with a lower contrast, but more subtle.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

lerp(covariant TextStyleSurfaceGroup? other, double t) TextStyleSurfaceGroup
Linearly interpolate with another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited