actions property
A map {actionName: action} of actions to perform when the text is tapped.
Implementation
final Map<String, VoidCallback>? actions;
A map {actionName: action} of actions to perform when the text is tapped.
final Map<String, VoidCallback>? actions;