BlocfulWidget<BLOC extends BlocPresentationMixin<STATE, EVENT> , STATE, EVENT> class
abstract
A widget that wraps your UI in a BlocPresentationListener and a BlocConsumer to be able to handle all events simultaniously
Example:
class SomePage extends BlocfulWidget<SomeCubit, SomeState, SomeEvent> {
const SomePage({super.key})
: super(onCreateBloc: SomeCubit());
@override
void onPresentationEvent(BuildContext context, SomeEvent event) {
SomeFunction();
}
@override
Widget builder(BuildContext context, SomeCubit bloc, SomeState state) {
return SomeWidget();
}
}
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- BlocfulWidget
Constructors
- BlocfulWidget({BLOC onCreateBloc(BuildContext)?, Key? key})
-
Creates a BlocfulWidget
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onCreateBloc → BLOC Function(BuildContext)?
-
Wraps the widget with a
BlocProviderwith the givenBLOCwhen this is not nullfinal - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
builder(
BuildContext context, BLOC bloc, STATE state) → Widget -
Builder function for the builder function of the
BlocConsumer -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
listener(
BuildContext context, BLOC bloc, STATE state) → void -
Listener function for the listener function of the
BlocConsumer -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onPresentationEvent(
BuildContext context, EVENT event) → void -
A function that defines what UI behaviour should be triggered when an
EVENThas taken place -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited