builder abstract method
Builder function for the builder function of the BlocConsumer
Implementation
Widget builder(BuildContext context, BLOC bloc, STATE state);
Builder function for the builder function of the BlocConsumer
Widget builder(BuildContext context, BLOC bloc, STATE state);