chopper/chopper library
Classes
- AuthenticationFailedError
- User not authenticated error
- BaseError
- Interface for the errors that could be returned
- ColorConverter
- A class that implements JsonConverter to convert Color objects to and from JSON.
- DateTimeConverter
- DateTimeConverter that parses and formats dates in the selected format. For example:
- JsonSerializableConverter
- JsonSeriablizableConverter Converter for chopper to convert json response to a dart object using json_serializable. Based of: https://hadrien-lejard.gitbook.io/chopper/faq#write-a-custom-jsonconverter
- NoInternetError
- The device is not connected error
- ServerError
- Http client error
- UnknownError
- Unknown error
Typedefs
-
JsonFactory<
T> = T Function(Map< String, dynamic> json) - Method signature for a function that creates a dart object from a json map.
- NoContent = dynamic
- A type representing an empty response body.
Exceptions / Errors
- JsonConverterException
- Thrown when a json response cannot be converted to the expected type.