JsonConverterException class
Thrown when a json response cannot be converted to the expected type.
- Implemented types
Constructors
- JsonConverterException(Type type, {required String message})
-
Creates a new JsonConverterException.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited