Paddings class
Constructors
- Paddings()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- all1 → const EdgeInsets
- all2 → const EdgeInsets
- all4 → const EdgeInsets
- all6 → const EdgeInsets
- all8 → const EdgeInsets
- all10 → const EdgeInsets
- all12 → const EdgeInsets
- all16 → const EdgeInsets
- all20 → const EdgeInsets
- all24 → const EdgeInsets
- all28 → const EdgeInsets
- all32 → const EdgeInsets
- all36 → const EdgeInsets
- all40 → const EdgeInsets
- all44 → const EdgeInsets
- all48 → const EdgeInsets
- bottom1 → const EdgeInsets
- bottom2 → const EdgeInsets
- bottom4 → const EdgeInsets
- bottom6 → const EdgeInsets
- bottom8 → const EdgeInsets
- bottom10 → const EdgeInsets
- bottom12 → const EdgeInsets
- bottom16 → const EdgeInsets
- bottom20 → const EdgeInsets
- bottom24 → const EdgeInsets
- bottom28 → const EdgeInsets
- bottom32 → const EdgeInsets
- bottom36 → const EdgeInsets
- bottom40 → const EdgeInsets
- bottom44 → const EdgeInsets
- bottom48 → const EdgeInsets
- empty → const EdgeInsets
- end1 → const EdgeInsetsDirectional
- end2 → const EdgeInsetsDirectional
- end4 → const EdgeInsetsDirectional
- end6 → const EdgeInsetsDirectional
- end8 → const EdgeInsetsDirectional
- end10 → const EdgeInsetsDirectional
- end12 → const EdgeInsetsDirectional
- end16 → const EdgeInsetsDirectional
- end20 → const EdgeInsetsDirectional
- end24 → const EdgeInsetsDirectional
- end28 → const EdgeInsetsDirectional
- end32 → const EdgeInsetsDirectional
- end36 → const EdgeInsetsDirectional
- end40 → const EdgeInsetsDirectional
- end44 → const EdgeInsetsDirectional
- end48 → const EdgeInsetsDirectional
- horizontal1 → const EdgeInsets
- horizontal2 → const EdgeInsets
- horizontal4 → const EdgeInsets
- horizontal6 → const EdgeInsets
- horizontal8 → const EdgeInsets
- horizontal10 → const EdgeInsets
- horizontal12 → const EdgeInsets
- horizontal16 → const EdgeInsets
- horizontal20 → const EdgeInsets
- horizontal24 → const EdgeInsets
- horizontal28 → const EdgeInsets
- horizontal32 → const EdgeInsets
- horizontal36 → const EdgeInsets
- horizontal40 → const EdgeInsets
- horizontal44 → const EdgeInsets
- horizontal48 → const EdgeInsets
- left1 → const EdgeInsets
- left2 → const EdgeInsets
- left4 → const EdgeInsets
- left6 → const EdgeInsets
- left8 → const EdgeInsets
- left10 → const EdgeInsets
- left12 → const EdgeInsets
- left16 → const EdgeInsets
- left20 → const EdgeInsets
- left24 → const EdgeInsets
- left28 → const EdgeInsets
- left32 → const EdgeInsets
- left36 → const EdgeInsets
- left40 → const EdgeInsets
- left44 → const EdgeInsets
- left48 → const EdgeInsets
- right1 → const EdgeInsets
- right2 → const EdgeInsets
- right4 → const EdgeInsets
- right6 → const EdgeInsets
- right8 → const EdgeInsets
- right10 → const EdgeInsets
- right12 → const EdgeInsets
- right16 → const EdgeInsets
- right20 → const EdgeInsets
- right24 → const EdgeInsets
- right28 → const EdgeInsets
- right32 → const EdgeInsets
- right36 → const EdgeInsets
- right40 → const EdgeInsets
- right44 → const EdgeInsets
- right48 → const EdgeInsets
- start1 → const EdgeInsetsDirectional
- start2 → const EdgeInsetsDirectional
- start4 → const EdgeInsetsDirectional
- start6 → const EdgeInsetsDirectional
- start8 → const EdgeInsetsDirectional
- start10 → const EdgeInsetsDirectional
- start12 → const EdgeInsetsDirectional
- start16 → const EdgeInsetsDirectional
- start20 → const EdgeInsetsDirectional
- start24 → const EdgeInsetsDirectional
- start28 → const EdgeInsetsDirectional
- start32 → const EdgeInsetsDirectional
- start36 → const EdgeInsetsDirectional
- start40 → const EdgeInsetsDirectional
- start44 → const EdgeInsetsDirectional
- start48 → const EdgeInsetsDirectional
- top1 → const EdgeInsets
- top2 → const EdgeInsets
- top4 → const EdgeInsets
- top6 → const EdgeInsets
- top8 → const EdgeInsets
- top10 → const EdgeInsets
- top12 → const EdgeInsets
- top16 → const EdgeInsets
- top20 → const EdgeInsets
- top24 → const EdgeInsets
- top28 → const EdgeInsets
- top32 → const EdgeInsets
- top36 → const EdgeInsets
- top40 → const EdgeInsets
- top44 → const EdgeInsets
- top48 → const EdgeInsets
- vertical1 → const EdgeInsets
- vertical2 → const EdgeInsets
- vertical4 → const EdgeInsets
- vertical6 → const EdgeInsets
- vertical8 → const EdgeInsets
- vertical10 → const EdgeInsets
- vertical12 → const EdgeInsets
- vertical16 → const EdgeInsets
- vertical20 → const EdgeInsets
- vertical24 → const EdgeInsets
- vertical28 → const EdgeInsets
- vertical32 → const EdgeInsets
- vertical36 → const EdgeInsets
- vertical40 → const EdgeInsets
- vertical44 → const EdgeInsets
- vertical48 → const EdgeInsets