logger/bolt_logger library

Classes

BoltCharge
Interface for creating BoltCharges to power the BoltLogger
BoltLogger
Super charge your logging and zap logs like Zeus with the BoltLogger.
BoltLoggerView
A widget that displays the logs stored in the MemoryCharge.
DebugConsoleCharge
A BoltCharge that logs output to the console with ANSI color support.
FileCharge
A BoltCharge that logs output to a file.
MemoryCharge
A BoltCharge that stores logs in memory. This will be used for viewing logs in the app. With the BoltLoggerView widget.
ZapEvent
A zap event that contains the lines of a log record and the origin LogRecord.

Extensions

ZapExtension on Object
Extension to zap messages.
ZapStackTraceExtension on StackTrace
StackTrace extension methods.