BoltLogger class
Super charge your logging and zap logs like Zeus with the BoltLogger.
Constructors
- BoltLogger()
-
Super charge your logging and zap logs like Zeus with the BoltLogger.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
charge(
List< BoltCharge> charges) → void - Add BoltCharge charges to the logger. This will start the logger if it is not already running. Without any charges, the logger will not output any logs.
-
discharge(
) → void - Discharge the logger and all charges.
-
getCharge(
String name) → BoltCharge? - Look up registered charge by name.
-
shock(
Object? message, {String? tag, Level level = Level.SEVERE}) → void -
Shock is a zap intensified! It zaps a log message default
levelofLevel.SEVERE. -
zap(
Object? message, {String? tag, Level level = Level.INFO}) → void -
Zap a log message with optional
tagandlevel.