logger/charges/bolt_charge library
Classes
- BoltCharge
- Interface for creating BoltCharges to power the BoltLogger
- DebugConsoleCharge
- A BoltCharge that logs output to the console with ANSI color support.
- FileCharge
- A BoltCharge that logs output to a file.
- MemoryCharge
- A BoltCharge that stores logs in memory. This will be used for viewing logs in the app. With the BoltLoggerView widget.