PaginatedScrollView<T> class
A widget that displays a list of items with pagination.
This widget is a CustomScrollView that displays a paginated list of items. It uses a PaginationState to manage the behavior of the widget. It also uses a NotificationListener to listen for scroll events and load more items when the user scrolls to the bottom of the list.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- PaginatedScrollView
Constructors
-
PaginatedScrollView({required PaginationState<
T> state, required Widget itemBuilder(BuildContext, T), void onLoadMore()?, Widget? topWidget, Widget? bottomWidget, Key? key}) -
Creates a new PaginatedScrollView.
const
Properties
- bottomWidget → Widget?
-
Optional widget to display at the bottom of the list.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemBuilder → Widget Function(BuildContext, T)
-
The builder for the items.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onLoadMore → void Function()?
-
The function to call when the user scrolls to the bottom of the list, to load more items.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
→ PaginationState<
T> -
The state of the pagination.
final
- topWidget → Widget?
-
Optional widget to display at the top of the list.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited