Highlight class
One explanation shown on top of a screen.
The real views are not changed for the showcase, so a target finds the widget to mark in the widget tree of the screen. Without a target only the explanation is shown. A highlight whose target is not built (yet) waits until it appears, for example behind a loading state.
Constructors
- Highlight({required String title, required String body, WidgetMatcher? target, EdgeInsets padding = Paddings.all8})
-
Creates a Highlight.
const
Properties
- body → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- padding → EdgeInsets
-
Space between the target and the ring around it.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- target → WidgetMatcher?
-
final
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
type<
T extends Widget> () → WidgetMatcher -
Matches the first widget of type
Ton the screen.